from random import randint
from time import sleep

from rich import print


def zombie_room(player):
    options = ["fight", "flee"]
    print()
    print("[dark_orange]You stumble into a room full of zombies.[/dark_orange]")
    sleep(1)
    print("Do you fight or flee?")
    choice = input(">> ").lower()
    if choice not in options:
        print("You cannot do that.")
        zombie_room(player)
    elif choice == "flee":
        sleep(1)
        player.consume_energy(2)
    elif choice == "fight":
        number = randint(0, 5)
        sleep(1)
        player.take_damage(5)
        print("You killed all the zombies.")
        if number == 5:
            sleep(1)
            print("A zombie dropped a sword.")
            player.pick_up_item("sword")



import os
from random import randint
from time import sleep

from rich import print

from scripts.player import Player
from scripts.rooms.empty_room import empty_room
from scripts.rooms.explosives_room import explosives_room
from scripts.rooms.rest_room import rest_room
from scripts.rooms.stranger_room import stranger_room
from scripts.rooms.walls_closing_room import walls_closing_room
from scripts.rooms.zombie_room import zombie_room


def clear_screen():
    if os.name == 'nt':
        _ = os.system('cls')
    else:
        _ = os.system('clear')


class Game:
    def __init__(self):
        self.player = Player(self)
        self.last_room = 0
        self.first_room = True
        self.room = 1
        self.win_level = 15

    @staticmethod
    def end(death_type):
        print(f"You ran out of {death_type.lower()} and died.")
        print("[red]GAME OVER[/red]")
        quit()

    def enter_room(self):
        rooms = [empty_room, rest_room, zombie_room, walls_closing_room, stranger_room, explosives_room]
        if self.first_room:
            number = randint(2, len(rooms) - 1)
            self.first_room = False
        else:
            while True:
                number = randint(0, len(rooms) - 1)
                if number != self.last_room:
                    break
        print(f"[green]Health:[/green] {self.player.health} / {self.player.max_health}")
        print(f"[green]Energy:[/green] {self.player.energy} / {self.player.max_energy}")
        print()
        print(f"Room {self.room}")
        print()
        rooms[number](self.player)
        self.last_room = number
        sleep(2)
        print()
        print()

    def run(self):
        clear_screen()
        print("[yellow]Welcome to the dungeon.[/yellow]")
        sleep(1)
        print()
        while self.room <= self.win_level:
            self.enter_room()
            while True:
                print("Are you ready to continue your journey?")
                choice = input(">> ").lower()
                continues = ["y", "ye", "ya", "yah", "yes", "yeah", "okay", "ok", "sure", "i guess", "yea",
                             "not really but okay"]
                if choice in continues:
                    print("You continue onwards.")
                    print()
                    sleep(1.5)
                    break
                else:
                    print("[red]In the dungeon, there is no escape.[/red]")
                    self.player.take_damage(2)
                    print()
                    sleep(1.5)
            self.room += 1
            clear_screen()
        print("[green]Congratulations! You reached the end of the dungeon and escaped.[/green]")
        print("[bold]You Win.[bold]")


game = Game()
game.run()



from time import sleep

from rich import print


def rest_room(player):
    print("[blue]You enter a peaceful room with a cosy bed.[/blue]")
    sleep(1)
    print("It is safe to rest. Do you sleep?")
    choice = input(">> ").lower()
    continues = ["y", "ye", "ya", "yah", "yes", "yeah", "okay", "ok", "sure", "i guess", "yea"]
    nos = ["n", "na", "no", "nah", "nope", "no way", "no thanks"]
    if choice in continues:
        print("You had a wonderful sleep.")
        sleep(1)
        player.rest()
    elif choice in nos:
        pass
    else:
        print("You cannot do that.")
        rest_room(player)



from time import sleep

from rich import print


def explosives_room(player):
    print("You walk into a room full of [red]explosives[/red].")
    sleep(1)
    print("[yellow]You hear a click beneath your feet as the explosives are triggered.[/yellow]")
    sleep(1)
    print("You can escape the blast if you sprint, or you can take the hit and preserve your energy.")
    sleep(1)
    print("Do you run for it?")
    choice = input(">> ")
    confirms = ["y", "ye", "ya", "yah", "yes", "yeah", "okay", "ok", "sure", "i guess", "yea"]
    denies = ["n", "na", "no", "nah", "nope", "no way", "no thanks"]
    if choice in confirms:
        player.consume_energy(8)
        print("You escaped the blast.")
    elif choice in denies:
        player.take_damage(10)
        print("You survived the explosions.")
    else:
        print("You cannot do that.")



from time import sleep

from rich import print


class Player:
    def __init__(self, game, max_health=60, max_energy=15):
        self.game = game
        self.max_health = max_health
        self.max_energy = max_energy
        self.health = self.max_health
        self.energy = self.max_energy
        self.inventory = dict()

    def take_damage(self, damage=5):
        self.health -= damage
        print(f"You took {damage} damage. Your health is at {self.health}")
        if self.health <= 0:
            self.health = 0
            sleep(1)
            self.game.end("health")

    def consume_energy(self, energy_used=5):
        self.energy -= energy_used
        print(f"You consumed {energy_used} energy. Current energy: {self.energy}")
        if self.energy <= 0:
            self.energy = 0
            sleep(1)
            self.game.end("energy")

    def pick_up_item(self, item):
        item = item.lower()
        if item not in self.inventory:
            self.inventory[item] = 1
        else:
            self.inventory[item] += 1
        print("New inventory: ")
        for i in self.inventory:
            print(f"{i.title()}: {self.inventory[i]}")

    def rest(self):
        self.health = self.max_health
        self.energy = self.max_energy
        print("You have recovered all your energy and health:")
        sleep(1)
        print(f"[green]Health:[/green] {self.health}")
        sleep(1)
        print(f"[green]Energy:[/green] {self.energy}")



from time import sleep

from rich import print


def walls_closing_room(player):
    print("You walk into a narrow hallway and hear a click.")
    sleep(1)
    print("[red]The walls creak and start moving towards you.[/red]")
    sleep(0.8)
    print("You sprint to the other side, escaping with minor scratches.")
    sleep(1)
    player.take_damage(3)
    sleep(1)
    player.consume_energy(5)



from math import floor
from random import randint
from time import sleep

from rich import print


def stranger_room(player):
    print("[yellow]You enter a dimly lit room. There is a strange man standing in the corner.[/yellow]")
    sleep(1)
    print("Do you approach the man?")
    choice = input(">> ")
    confirms = ["yes", "y", "yep", "ok", "okay", "sure", "ye", "yeah", "yea",
                "yah"]
    if choice in confirms:
        if randint(0, 1) == 0:
            sleep(0.8)
            print("[green]The strange man turns to you and smiles.[/green]")
            sleep(1)
            print("You feel a warm and calming energy.")
            sleep(1)
            player.energy = player.max_energy
            print("[green]Your energy is restored.[green]")
            sleep(1)
            print(f"[green]Energy: {player.energy}[/green]")
        else:
            print("[red]The strange man turns to you and scowls.[/red]")
            sleep(1)
            print("[red]You feel a sharp pain and a cloud of fog enters your mind.[/red]")
            sleep(1)
            player.take_damage(floor(player.health / 100 * 20))  # damage 20% of current health (rounded)
            sleep(1)
            player.consume_energy(floor(player.energy / 100 * 50))  # consume 50% of current energy (rounded)



from time import sleep

from rich import print


def empty_room(_player):  # _player so that it takes the same parameters as the other rooms
    print("[blue]You enter an empty room. There's nothing to do.[/blue]")
    sleep(1)
